% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quantileResidualTests.R
\name{quantileResidualTests}
\alias{quantileResidualTests}
\title{Quantile residual tests for GMAR or StMAR model}
\usage{
quantileResidualTests(data, p, M, params, StMAR = FALSE, restricted = FALSE,
  constraints = FALSE, R, lagsAC = c(1, 2, 4, 6, 8, 10), lagsCH = c(1, 2,
  4, 6, 8, 10), nsimu = 2000, printRes = TRUE)
}
\arguments{
\item{data}{a numeric vector or column matrix containing the data. \code{NA} values are not supported.}

\item{p}{a positive integer specifying the order of AR coefficients.}

\item{M}{a positive integer specifying the number of mixture components or regimes.}

\item{params}{a real valued parameter vector specifying the model.
\describe{
  \item{For \strong{non-restricted} models:}{
    \describe{
      \item{For \strong{GMAR} model:}{Size \eqn{(M(p+3)-1x1)} vector \strong{\eqn{\theta}}\eqn{=}(\strong{\eqn{\upsilon_{1}}},...,\strong{\eqn{\upsilon_{M}}},
        \eqn{\alpha_{1},...,\alpha_{M-1}}), where \strong{\eqn{\upsilon_{m}}}\eqn{=(\phi_{m,0},}\strong{\eqn{\phi_{m}}}\eqn{,
        \sigma_{m}^2)} and \strong{\eqn{\phi_{m}}}=\eqn{(\phi_{m,1},...,\phi_{m,p}), m=1,...,M}.}
      \item{For \strong{StMAR} model:}{Size \eqn{(M(p+4)-1x1)} vector (\strong{\eqn{\theta, \nu}})\eqn{=}(\strong{\eqn{\upsilon_{1}}},...,\strong{\eqn{\upsilon_{M}}},
        \eqn{\alpha_{1},...,\alpha_{M-1}, \nu_{1},...,\nu_{M}}).}
      \item{With \strong{linear constraints}:}{Replace the vectors \strong{\eqn{\phi_{m}}} with vectors \strong{\eqn{\psi_{m}}} and provide a  list of constraint
        matrices \strong{R} that satisfy \strong{\eqn{\phi_{m}}}\eqn{=}\strong{\eqn{R_{m}\psi_{m}}} for all \eqn{m=1,...,M}, where
        \strong{\eqn{\psi_{m}}}\eqn{=(\psi_{m,1},...,\psi_{m,q_{m}})}.}
    }
  }
  \item{For \strong{restricted} models:}{
    \describe{
      \item{For \strong{GMAR} model:}{Size \eqn{(3M+p-1x1)} vector \strong{\eqn{\theta}}\eqn{=(\phi_{1,0},...,\phi_{M,0},}\strong{\eqn{\phi}}\eqn{,
        \sigma_{1}^2,...,\sigma_{M}^2,\alpha_{1},...,\alpha_{M-1})}, where \strong{\eqn{\phi}}=\eqn{(\phi_{1},...,\phi_{M})}.}
      \item{For \strong{StMAR} model:}{Size \eqn{(4M+p-1x1)} vector (\strong{\eqn{\theta, \nu}})\eqn{=(\phi_{1,0},...,\phi_{M,0},}\strong{\eqn{\phi}}\eqn{,
        \sigma_{1}^2,...,\sigma_{M}^2,\alpha_{1},...,\alpha_{M-1}, \nu_{1},...,\nu_{M})}.}
      \item{With \strong{linear constraints}:}{Replace the vector \strong{\eqn{\phi}} with vector \strong{\eqn{\psi}} and provide a constraint matrix
        \strong{\eqn{R}} that satisfies \strong{\eqn{\phi}}\eqn{=}\strong{\eqn{R\psi}}, where
        \strong{\eqn{\psi}}\eqn{=(\psi_{1},...,\psi_{q})}.}
    }
  }
}
Symbol \eqn{\phi} denotes an AR coefficient, \eqn{\sigma^2} a variance, \eqn{\alpha} a mixing weight and \eqn{v} a degrees of
freedom parameter.
Note that in the case \strong{M=1} the parameter \eqn{\alpha} is dropped, and in the case of \strong{StMAR} model
the degrees of freedom parameters \eqn{\nu_{m}} have to be larger than \eqn{2}.}

\item{StMAR}{an (optional) logical argument stating whether StMAR model should be considered instead of GMAR model. Default is \code{FALSE}.}

\item{restricted}{an (optional) logical argument stating whether the AR coefficients \eqn{\phi_{m,1},...,\phi_{m,p}} are restricted
to be the same for all regimes. Default is \code{FALSE}.}

\item{constraints}{an (optional) logical argument stating whether general linear constraints should be applied to the model. Default is \code{FALSE}.}

\item{R}{Specifies the linear constraints.
\describe{
\item{For \strong{non-restricted} models:}{a list of size \eqn{(pxq_{m})} constraint matrices \strong{\eqn{R_{m}}} of full column rank
  satisfying \strong{\eqn{\phi_{m}}}\eqn{=}\strong{\eqn{R_{m}\psi_{m}}} for all \eqn{m=1,...,M}, where
  \strong{\eqn{\phi_{m}}}\eqn{=(\phi_{m,1},...,\phi_{m,p})} and \strong{\eqn{\psi_{m}}}\eqn{=(\psi_{m,1},...,\psi_{m,q_{m}})}.}
\item{For \strong{restricted} models:}{a size \eqn{(pxq)} constraint matrix \strong{\eqn{R}} of full column rank satisfying
  \strong{\eqn{\phi}}\eqn{=}\strong{\eqn{R\psi}}, where \strong{\eqn{\phi}}\eqn{=(\phi_{1},...,\phi_{p})} and
  \strong{\eqn{\psi}}\eqn{=\psi_{1},...,\psi_{q}}.}
}
Symbol \eqn{\phi} denotes an AR coefficient. Note that regardless of any constraints, the nominal order of AR coefficients is alway \code{p} for all regimes.
This argument is ignored if \code{constraints==FALSE}.}

\item{lagsAC}{an (optional) numeric vector of positive integers specifying the lags for which autocorrelation is tested. Default is \code{c(1, 2, 4, 6, 8, 10)}.}

\item{lagsCH}{an (optional) numeric vector of positive integers specifying the lags for which conditional heteroscedasticy is tested. Default is \code{c(1, 2, 4, 6, 8, 10)}.}

\item{nsimu}{an (optional) positive integer specifying to how many simulated observations the covariance matrix Omega should be based on. If smaller than data size, then omega will be based on the given data. Default is 2000.}

\item{printRes}{an (optional) logical argument defining wether results should be printed or not. Default is \code{TRUE}.}
}
\value{
a list of data frames containing the test results:
  \describe{
  \item{\code{$normality}}{A data frame containing results from the normality test.
    \code{$testStat} containing the test statistic and \code{$pvalue} containing the corresponding p-value.}
  \item{\code{$autocorrelation}}{A data frame containing results from the autocorrelation tests.
    \code{$testStat} containing the test statistics and \code{$pvalue} containing the corresponding p-values.
    \code{$indStat} containing uncentered sample autocovariances of the quantile residuals for each lag,
    and \code{$stdError} containing their approximate standard errors.}
  \item{\code{$cond.heteroscedasticity}}{A data frame containing results from the conditional heteroskedasticity tests.
    \code{$testStat} containing the test statistics and \code{$pvalue} containing the corresponding p-values.
    \code{$indStat} containing the individual statistics assiociated with each lag,
    and \code{$stdError} containing their approximate standard errors.}
  }
}
\description{
\code{quantileResidualTests} performs quantile residual tests for GMAR or StMAR model, testing normality, autocorrelation and conditional heteroscedasticy.
}
\details{
\code{NA} values mean that it was not (numerically) possible for the code to calculate all the necessary estimates for the tests.
  This may suggest that the model is misspecified.

For details about the quantile residual tests see \emph{Kalliovirta 2012} from the references.
}
\section{Printed results}{

  The results from the tests are printed so that the letter "N" means normality test, "A" autocorrelation test
  and "H" conditional heteroscedasticity test. The numbers right next to "A" and "H" indicate the number of lags used
  in each test. The statistics following them are the corresponding test statistics and p-values.
}

\section{Suggested packages}{

  Install the suggested package "gsl" for faster evaluations in the cases of StMAR models.
  For large StMAR models with large data the evaluations may take significantly long time without
  the package "gsl".
}

\examples{
\donttest{
# GMAR model
params13 <- c(1.4, 0.88, 0.26, 2.46, 0.82, 0.74, 5.0, 0.68, 5.2, 0.72, 0.2)
tests13 <- quantileResidualTests(VIX, 1, 3, params13)

# Restricted GMAR model, using the given data instead of simulated data
params12r <- c(1.4, 1.8, 0.88, 0.29, 3.18, 0.84)
tests12r <- quantileResidualTests(VIX, 1, 2, params12r, restricted=TRUE, nsimu=1)

# StMAR model
params12t <- c(1.38, 0.88, 0.27, 3.8, 0.74, 3.15, 0.8, 120, 3.6)
tests12t <- quantileResidualTests(VIX, 1, 2, params12t, StMAR=TRUE,
                                  lagsAC=c(1, 5, 10), lagsCH=c(1, 5, 10))

# GMAR model as a mixture of AR(2) and AR(1) models
R <- list(diag(1, ncol=2, nrow=2), as.matrix(c(1, 0)))
params22c <- c(1.2, 0.85, 0.04, 0.3, 3.3, 0.77, 2.8, 0.77)
tests22c <- quantileResidualTests(VIX, 2, 2, params22c, constraints=TRUE, R=R)

# Such StMAR(3,2) that the AR coefficients are restricted to be
# the same for both regimes and that the second AR coefficients are
# constrained to zero.
params32trc <- c(2.2, 1.8, 0.88, -0.03, 2.4, 0.27, 0.40, 3.9, 1000)
qr32trc <- quantileResidualTests(VIX, 3, 2, params32trc, StMAR=TRUE,
                                  restricted=TRUE, constraints=TRUE,
                                  R=matrix(c(1, 0, 0, 0, 0, 1), ncol=2),
                                  lagsAC=c(1, 5, 10), lagsCH=c(1, 5, 10))
}
}
\references{
\itemize{
   \item Kalliovirta L., Meitz M. and Saikkonen P. (2015) Gaussian Mixture Autoregressive model for univariate time series.
         \emph{Journal of Time Series Analysis}, \strong{36}, 247-266.
   \item Kalliovirta L. (2012) Misspecification tests based on quantile residuals.
         \emph{The Econometrics Journal}, \strong{15}, 358-393.
   \item Lutkepohl H. New Introduction to Multiple Time Series Analysis,
         \emph{Springer}, 2005.
   \item Galbraith, R., Galbraith, J., (1974). On the inverses of some patterned matrices arising
           in the theory of stationary time series. \emph{Journal of Applied Probability} \strong{11}, 63-71.
   \item References regarding the StMAR model and general linear constraints will be updated after they are published.
 }
}
